@@ -2,10 +2,13 @@ import json
 from random import Random
 from wickedhot import one_hot_encode as ohe
 from wickedhot.form_generator import encoder_package_to_form_elements, encoder_package_to_html_page
+from wickedhot.transform_stream import transform_stream
 
 
 class OneHotEncoder:
-    def __init__(self, categorical_cols, numeric_cols, max_levels_default=10000, omit_cols=None):
+    def __init__(self, categorical_cols, numeric_cols, max_levels_default=10000,
+                 omit_cols=None, default_numeric=-999):
+
         assert max_levels_default > 0
         self.max_levels_default = max_levels_default
         self.numeric_cols = numeric_cols
@@ -15,6 +18,9 @@ class OneHotEncoder:
         self.decoder = None
         self.index_lookup = None
         self.numeric_stats = None
+        self.failed_numeric_conversion_stats = {}
+        self.default_numeric = default_numeric
+        self.encoded_stream_failed_numeric_conversion_stats = {}
 
         if isinstance(categorical_cols, list):
             self.categorical_n_levels_dict = {k: self.max_levels_default for k in categorical_cols}
@@ -25,12 +31,33 @@ class OneHotEncoder:
         else:
             raise ValueError('categorical_cols must be a list or dictionary')
 
+    def _transform_stream(self, stream_of_dicts):
+        return transform_stream(stream_of_dicts,
+                                self.numeric_cols,
+                                num_failed=self.failed_numeric_conversion_stats,
+                                default_numeric=self.default_numeric)
+
+    def _transform_row(self, row):
+        result = transform_stream([row],
+                                  self.numeric_cols,
+                                  default_numeric=self.default_numeric,
+                                  num_failed=self.encoded_stream_failed_numeric_conversion_stats)
+        result = list(result)
+        assert len(result) == 1
+        return result[0]
+
     def load_from_data_stream(self, stream_of_dicts):
+        stream_of_dicts = self._transform_stream(stream_of_dicts)
+
         self.one_hot_encoder_dicts = ohe.get_one_hot_encoder_dicts_from_data_stream(stream_of_dicts,
                                                                                     self.categorical_n_levels_dict)
         self._get_encoder_decoder()
 
     def add_numeric_stats(self, stream_of_dicts):
+        # reset this
+        self.failed_numeric_conversion_stats = {}
+
+        stream_of_dicts = self._transform_stream(stream_of_dicts)
 
         random_generator = Random()
         random_generator.seed(265472)
@@ -43,7 +70,9 @@ class OneHotEncoder:
                 'categorical_n_levels_dict': self.categorical_n_levels_dict,
                 'one_hot_encoder_dicts': self.one_hot_encoder_dicts,
                 'numeric_stats': self.numeric_stats,
-                'omit_cols': self.omit_cols}
+                'omit_cols': self.omit_cols,
+                'default_numeric': self.default_numeric,
+                'failed_numeric_conversion_stats': self.failed_numeric_conversion_stats}
 
         return data
 
@@ -58,6 +87,8 @@ class OneHotEncoder:
         self.one_hot_encoder_dicts = data_object['one_hot_encoder_dicts']
         self.numeric_stats = data_object['numeric_stats']
         self.omit_cols = data_object['omit_cols']
+        self.default_numeric = data_object['default_numeric']
+        self.failed_numeric_conversion_stats = data_object['failed_numeric_conversion_stats']
 
         self._get_encoder_decoder()
 
@@ -76,7 +107,8 @@ class OneHotEncoder:
         self.encoder, self.decoder = ohe.get_line_encoder_and_decoder(self.index_lookup)
 
     def encode_row(self, row):
-        return self.encoder(row)
+        row_transformed = self._transform_row(row)
+        return self.encoder(row_transformed)
 
     def decode_row(self, row):
         return self.decoder(row)
@@ -98,6 +130,9 @@ class OneHotEncoder:
 
     def encode_data_stream(self, stream):
         # generator
+
+        # reset this
+        self.encoded_stream_failed_numeric_conversion_stats = {}
         return (self.encode_row(row) for row in stream)
 
     def encode_data(self, stream):
@@ -119,6 +154,9 @@ class OneHotEncoder:
         :param post_url: url that form will be submitted to on submission
         :param initial_values: dict of initial values for form, otherwise , it chooses
             them by itself
+        :param extra_numerics: extra numeric fields to add
+        :param extra_categoricals: extra categorical fields to add
+        :param omitted_fields: fields to omit
         :return: html_header, div_text
         """
         return encoder_package_to_form_elements(self.package_data(),
@@ -137,6 +175,9 @@ class OneHotEncoder:
         :param post_url: url that form will be submitted to on submission
         :param initial_values: dict of initial values for form, otherwise , it chooses
             them by itself
+        :param extra_numerics: extra numeric fields to add
+        :param extra_categoricals: extra categorical fields to add
+        :param omitted_fields: fields to omit
         :return:
         """
         return encoder_package_to_html_page(self.package_data(),
